@@ -654,19 +654,15 @@ final class WP_Theme implements ArrayAccess {
 	private function markup_header( $header, $value, $translate ) {
 		switch ( $header ) {
 			case 'Name' :
-				if ( empty( $value ) ) {
-					$value = esc_html( $this->get_stylesheet() );
-				}
+				if ( empty( $value ) )
+					$value = $this->get_stylesheet();
 				break;
 			case 'Description' :
 				$value = wptexturize( $value );
 				break;
 			case 'Author' :
 				if ( $this->get('AuthorURI') ) {
-					static $attr = null;
-					if ( ! isset( $attr ) )
-						$attr = esc_attr__( 'Visit author homepage' );
-					$value = sprintf( '<a href="%1$s" title="%2$s">%3$s</a>', $this->display( 'AuthorURI', true, $translate ), $attr, $value );
+					$value = sprintf( '<a href="%1$s">%2$s</a>', $this->display( 'AuthorURI', true, $translate ), $value );
 				} elseif ( ! $value ) {
 					$value = __( 'Anonymous' );
 				}
@@ -727,7 +723,7 @@ final class WP_Theme implements ArrayAccess {
 				}
 
 				return $value;
-				break;
+
 			default :
 				$value = translate( $value, $this->get('TextDomain') );
 		}
